@@ -14,6 +14,7 @@ from ei.core import defaults
 from ei.core.fields import Field
 from ei.core.service import BaseAwsService
 from ei.core.concurrency import bulk_action
+from ei.core.exceptions import BaseError
 from ei.core.exceptions import PreflightError
 from ei.core.exceptions import WrongRegionError
 from ei.core.exceptions import WrongAccountError
@@ -25,9 +26,6 @@ if typing.TYPE_CHECKING:
     from typing import Callable  # noqa: F401
 
 
-SUBJECTS = ['Region', 'Account']
-
-
 def create_application(apps: List['Typeable']) -> Typer:
     cli = CliGroup(
         name='ei',
@@ -53,22 +51,10 @@ def _get_typer(name: str, help: str) -> Typer:
 
 def _preflight() -> None:
     if not all(defaults.CONFIGS):
-        raise PreflightError('\n'.join((
-            (
-                'Environment variables are not fulfilled.'
-                ' Check the environment variables.'
-            ),
-            '',
-            f'{defaults.EI_ACCOUNT_IDS=}',
-            f'{defaults.EI_REGIONS=}',
-            f'{defaults.EI_ASSUME_ROLE_ARN_PATTERN=}',
-            f'{defaults.EI_ASSUME_ROLE_SESSION_NAME=}',
-            f'{defaults.AWS_REGION=}',
-            f'{defaults.AWS_ACCESS_KEY_ID=}',
-            f'{defaults.AWS_SECRET_ACCESS_KEY=}',
-            f'{defaults.AWS_SECURITY_TOKEN=}',
-            f'{defaults.AWS_SESSION_EXPIRATION=}',
-        )))
+        raise PreflightError((
+            'Environment variables are not fulfilled.'
+            ' Check the environment variables.'
+        ))
 
 
 def _serialize_data_as_list(fields: Iterable[Field],
@@ -110,6 +96,8 @@ class BaseCliApp(Typeable):
     # more additional fields for show resource
     detail_fields: tuple = ()
 
+    stats_fields = ['Region', 'Account']
+
     _service: BaseAwsService
 
     def __init__(self) -> None:
@@ -133,6 +121,29 @@ class BaseCliApp(Typeable):
                 f'({defaults.EI_ACCOUNT_IDS=})'
             )
 
+    def _preflight(self, region: str, account_id: str) -> None:
+        try:
+            _preflight()
+            self._validate_region(region)
+            self._validate_acocunt_id(account_id)
+
+        except PreflightError as e:
+            self._console.print(e, style='red')
+            self._console.print('\n'.join([
+                '',
+                f'{defaults.EI_ACCOUNT_IDS=}',
+                f'{defaults.EI_REGIONS=}',
+                f'{defaults.EI_STS_ASSUME_ROLE_ARN_PATTERN=}',
+                f'{defaults.EI_STS_ASSUME_ROLE_SESSION_NAME=}',
+                f'{defaults.AWS_REGION=}',
+                f'{defaults.AWS_ACCESS_KEY_ID=}',
+                f'{defaults.AWS_SECRET_ACCESS_KEY=}',
+                f'{defaults.AWS_SECURITY_TOKEN=}',
+                f'{defaults.AWS_SESSION_EXPIRATION=}',
+            ]))
+
+            raise e
+
     def list(
             self,
             long: bool = False,
@@ -146,12 +157,9 @@ class BaseCliApp(Typeable):
         """
 
         try:
-            _preflight()
-            self._validate_region(region)
-            self._validate_acocunt_id(account_id)
+            self._preflight(region, account_id)
 
-        except PreflightError as e:
-            self._console.print(e)
+        except PreflightError:
             return 1
 
         if long:
@@ -186,7 +194,7 @@ class BaseCliApp(Typeable):
 
             if stat:
                 stats_dict: dict = {}
-                for subject in SUBJECTS:
+                for subject in self.stats_fields:
                     stats_dict[subject] = defaultdict(int)
 
                     for item in results:
@@ -195,13 +203,17 @@ class BaseCliApp(Typeable):
                 self._console.print(
                     f'{len(serialized_results)} "{self.name}" items.')
 
-                for subject in SUBJECTS:
+                for subject in self.stats_fields:
+                    results = list(stats_dict[subject].items())
+                    results.sort(
+                        key=lambda x: x[1], reverse=True)  # type: ignore
+
                     self._console.print(f'\n* per {subject}')
-                    for key, count in stats_dict[subject].items():
+                    for key, count in results:
                         self._console.print(
                             f'  - "{key}": {count} items.')
 
-        except ClientError as e:
+        except (BaseError, ClientError) as e:
             print(e)
             return 1
 
@@ -214,12 +226,10 @@ class BaseCliApp(Typeable):
             account_id: str = '') -> int:
         """Show resource
         """
-        try:
-            _preflight()
-            self._validate_region(region)
 
-        except PreflightError as e:
-            self._console.print(e)
+        try:
+            self._preflight(region, account_id)
+        except PreflightError:
             return 1
 
         try:
@@ -230,7 +240,7 @@ class BaseCliApp(Typeable):
             table = detail_table(serialized_result)
             self._console.print(table)
 
-        except ClientError as e:
+        except (BaseError, ClientError) as e:
             print(e)
             return 1
 
