@@ -4,6 +4,7 @@ from ei.core.cli import create_application
 from ei.views.cli import ec2
 from ei.views.cli import elasticache
 from ei.views.cli import rds
+from ei.views.cli import s3
 
 
 if typing.TYPE_CHECKING:
@@ -14,6 +15,7 @@ APPS = [
     ec2.group,
     elasticache.group,
     rds.group,
+    s3.group
 ]  # type: typing.List[Typeable]
 
 
