@@ -1,29 +1,6 @@
-from contextlib import contextmanager
-from contextlib import _GeneratorContextManager
-from typing import Any
-from typing import Callable
-from typing import Generator
 from unittest import mock
 
-from ei.core.service import BaseAwsService
-
-
-@contextmanager
-def with_dummy(account_id: str, region: str, service_name: str) -> Generator:
-    yield ''
-
-
-class DummyAwsService(BaseAwsService):
-    service_name: str = 'dummy'
-    _sessioncontext: Callable[..., _GeneratorContextManager] = with_dummy
-
-    @classmethod
-    def _list(cls, client: Any) -> Any:
-        return [{}]
-
-    @classmethod
-    def _show(cls, client: Any, id: str) -> Any:
-        return [{}]
+from tests.mocks.app import DummyAwsService
 
 
 @mock.patch('ei.core.defaults.AWS_REGION', 'region-1')
